==> hs-zlib-0.5.2.0p5.tgz: lib/ghc/zlib-0.5.2.0/register.sh <==
#!/bin/sh
echo 'name: zlib
version: 0.5.2.0
id: zlib-0.5.2.0-7acfb4dd7cb77e3a4b5beb3b9b160b08

license: BSD3
copyright: (c) 2006-2008 Duncan Coutts
maintainer: Duncan Coutts <duncan@haskell.org>
stability: provisional
homepage:
package-url:
description: This package provides a pure interface for compressing and
             decompressing streams of data represented as lazy
             '\''ByteString'\''s. It uses the zlib C library so it has high
             performance. It supports the \"zlib\", \"gzip\" and \"raw\"
             compression formats.
             .
             It provides a convenient high level API suitable for most
             tasks and for the few cases where more control is needed it
             provides access to the full zlib feature set.
category: Codec
author: Duncan Coutts <duncan@haskell.org>
pkgpath: archivers/hs-zlib
exposed: True
exposed-modules: Codec.Compression.GZip Codec.Compression.Zlib
                 Codec.Compression.Zlib.Raw Codec.Compression.Zlib.Internal
hidden-modules: Codec.Compression.Zlib.Stream
import-dirs: /usr/local/lib/ghc/zlib-0.5.2.0
library-dirs: /usr/local/lib/ghc/zlib-0.5.2.0
hs-libraries: HSzlib-0.5.2.0
extra-libraries: z
extra-ghci-libraries:
include-dirs:
includes: zlib.h
depends: base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
         bytestring-0.9.1.7-41dd05a497806d68d10ffae5438a0632
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-zlib-0.5.2.0/html/zlib.haddock
haddock-html: /usr/local/share/doc/hs-zlib-0.5.2.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-zlib-0.5.3.1.tgz: lib/ghc/zlib-0.5.3.1/register.sh <==
#!/bin/sh
echo 'name: zlib
version: 0.5.3.1
id: zlib-0.5.3.1-a78f28b72a90bc6d93acffb0c82dfef3

license: BSD3
copyright: (c) 2006-2008 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
stability:
homepage:
package-url:
description: This package provides a pure interface for compressing and
             decompressing streams of data represented as lazy
             '\''ByteString'\''s. It uses the zlib C library so it has high
             performance. It supports the \"zlib\", \"gzip\" and \"raw\"
             compression formats.
             .
             It provides a convenient high level API suitable for most
             tasks and for the few cases where more control is needed it
             provides access to the full zlib feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
pkgpath: archivers/hs-zlib
exposed: True
exposed-modules: Codec.Compression.GZip Codec.Compression.Zlib
                 Codec.Compression.Zlib.Raw Codec.Compression.Zlib.Internal
hidden-modules: Codec.Compression.Zlib.Stream
import-dirs: /usr/local/lib/ghc/zlib-0.5.3.1
library-dirs: /usr/local/lib/ghc/zlib-0.5.3.1
hs-libraries: HSzlib-0.5.3.1
extra-libraries: z
extra-ghci-libraries:
include-dirs:
includes: zlib.h
depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-zlib-0.5.3.1/html/zlib.haddock
haddock-html: /usr/local/share/doc/hs-zlib-0.5.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
